mailr5920 - /1.3/test_suite/system_tests/consistency_tests.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on April 21, 2008 - 15:36:
Author: bugman
Date: Mon Apr 21 15:02:56 2008
New Revision: 5920

URL: http://svn.gna.org/viewcvs/relax?rev=5920&view=rev
Log:
The proton type is now set in the consistency testing system test.

This mimicks the J(w) mapping changes of r5745.


Modified:
    1.3/test_suite/system_tests/consistency_tests.py

Modified: 1.3/test_suite/system_tests/consistency_tests.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/test_suite/system_tests/consistency_tests.py?rev=5920&r1=5919&r2=5920&view=diff
==============================================================================
--- 1.3/test_suite/system_tests/consistency_tests.py (original)
+++ 1.3/test_suite/system_tests/consistency_tests.py Mon Apr 21 15:02:56 2008
@@ -76,10 +76,11 @@
         for dataSet in xrange(len(dataPaths)):
             self.relax.interpreter._Relax_data.read(dataTypes[dataSet][0], 
dataTypes[dataSet][1], dataTypes[dataSet][2], dataPaths[dataSet])
 
         # Set r, csa, and the heteronucleus type.
         self.relax.interpreter._Value.set(NH_BOND_LENGTH, 'bond_length')
         self.relax.interpreter._Value.set(N15_CSA, 'csa')
         self.relax.interpreter._Value.set('15N', 'heteronucleus')
+        self.relax.interpreter._Value.set('1H', 'proton')
 
         # Set the angle between the 15N-1H vector and the principal axis of 
@@ -76,10 +76,11 @@
dataTypes[dataSet][1], dataTypes[dataSet][2], dataPaths[dataSet])
 
-        # Set r, csa, and the heteronucleus type.
+        # Set r, csa, heteronucleus type, and proton type.
         self.relax.interpreter._Value.set(NH_BOND_LENGTH, 'bond_length')
         self.relax.interpreter._Value.set(N15_CSA, 'csa')
the 15N chemical shift tensor
         self.relax.interpreter._Value.set(15.7, 'orientation')




Related Messages


Powered by MHonArc, Updated Mon Apr 21 15:40:28 2008